@@ -51,25 +51,38 @@ package com.openexchange.publish.microformats;
 
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
-import java.net.URLDecoder;
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.TimeZone;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import com.openexchange.context.ContextService;
+import com.openexchange.api2.OXException;
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.groupware.contact.ContactInterface;
+import com.openexchange.groupware.contact.ContactInterfaceDiscoveryService;
+import com.openexchange.groupware.container.Contact;
+import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.i18n.MicroformatStrings;
+import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.java.Strings;
 import com.openexchange.publish.Publication;
 import com.openexchange.publish.PublicationDataLoaderService;
+import com.openexchange.publish.microformats.osgi.StringTranslator;
 import com.openexchange.publish.microformats.tools.UncloseableWriter;
+import com.openexchange.publish.tools.PublicationSession;
 import com.openexchange.templating.OXTemplate;
-import com.openexchange.templating.TemplateService;
+import com.openexchange.user.UserService;
 
 /**
  * {@link MicroformatServlet}
@@ -78,38 +91,68 @@ import com.openexchange.templating.TemplateService;
  */
 public class MicroformatServlet extends OnlinePublicationServlet {
 
-    private static final Map<String, OXMFPublicationService> publishers = new HashMap<String, OXMFPublicationService>();
+    private static final long serialVersionUID = 6727750981539640363L;
 
-    private static final Map<String, String> templateNames = new HashMap<String, String>();
+    private static final Map<String, OXMFPublicationService> publishers = new HashMap<String, OXMFPublicationService>();
 
     private static final Log LOG = LogFactory.getLog(MicroformatServlet.class);
 
     private static final String MODULE = "module";
 
     private static final String SITE = "site";
-    
+
     private static final String CONTEXTID = "ctx";
 
     private static PublicationDataLoaderService dataLoader = null;
 
-    private static TemplateService templateService = null;
-    
+
     private static Map<String, Map<String, Object>> additionalTemplateVariables = new HashMap<String, Map<String, Object>>();
 
+    private static UserService userService;
+
+    private static StringTranslator translator;
+
+    private static ConfigurationService configService;
+
+    private static ContactInterfaceDiscoveryService contacts;
+
+    private static final DateFormat DATE_FORMAT = new SimpleDateFormat("yyyy-MM-dd");
+    static {
+        DATE_FORMAT.setTimeZone(TimeZone.getTimeZone("UTC"));
+    }
+
+    private static final DateFormat TIME_FORMAT = new SimpleDateFormat("yyyy-MM-dd H:m:s.S z");
+    static {
+        TIME_FORMAT.setTimeZone(TimeZone.getTimeZone("UTC"));
+    }
+
     public static void setPublicationDataLoaderService(PublicationDataLoaderService service) {
         dataLoader = service;
     }
 
-    public static void setTemplateService(TemplateService service) {
-        templateService = service;
+
+    public static void setUserService(UserService service) {
+        userService = service;
     }
 
-    public static void registerType(String module, OXMFPublicationService publisher, String templateName, Map<String, Object> additionalVars) {
+    public static void setStringTranslator(StringTranslator trans) {
+        translator = trans;
+    }
+    
+    public static void setConfigService(ConfigurationService confService) {
+        configService = confService;
+    }
+
+    public static void registerType(String module, OXMFPublicationService publisher, Map<String, Object> additionalVars) {
         publishers.put(module, publisher);
-        templateNames.put(module, templateName);
         additionalTemplateVariables.put(module, additionalVars);
     }
 
+    public static void setContactInterfaceDiscoveryService(ContactInterfaceDiscoveryService service) {
+        contacts = service;
+    }
+
+
     @Override
     protected void service(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         try {
@@ -137,16 +180,30 @@ public class MicroformatServlet extends OnlinePublicationServlet {
             Collection<? extends Object> loaded = dataLoader.load(publication);
 
             HashMap<String, Object> variables = new HashMap<String, Object>();
+            User user = getUser(publication);
+            Contact userContact = getContact(new PublicationSession(publication), publication.getContext(), user.getContactId());
+            
             variables.put(getCollectionName(module), loaded);
             variables.put("publication", publication);
             variables.put("request", req);
-            
-            if(additionalTemplateVariables.containsKey(module)) {
+            variables.put("dateFormat", DATE_FORMAT);
+            variables.put("timeFormat", TIME_FORMAT);
+            String admin = configService.getProperty("PUBLISH_REVOKE");
+            if(admin == null || admin.equals(""))
+                admin = userService.getUser(ctx.getMailadmin(), ctx).getMail();
+            String privacyText = formatPrivacyText(
+                getPrivacyText(user),
+                admin,
+                user,
+                new Date());
+            variables.put("privacy", privacyText ); //TODO Use lastmodified once someone implements this.
+            variables.put("userContact", userContact); 
+
+            if (additionalTemplateVariables.containsKey(module)) {
                 variables.putAll(additionalTemplateVariables.get(module));
             }
-            String templateName = templateNames.get(module);
-            OXTemplate template = templateService.loadTemplate(templateName);
-
+            
+            OXTemplate template = publisher.loadTemplate(publication);
             template.process(variables, new UncloseableWriter(resp.getWriter()));
 
         } catch (Throwable t) {
@@ -156,14 +213,23 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         }
     }
 
-    private String getCollectionName(String module) {
-        if (module.equals("contacts")) {
-            return "contacts";
-        }
-        return null;
+    private Contact getContact(PublicationSession publicationSession, Context context, int contactId) throws OXException {
+        ContactInterface contactInterface = contacts.getContactInterfaceProvider(FolderObject.SYSTEM_LDAP_FOLDER_ID, context.getContextId()).newContactInterface(publicationSession);
+        Contact contact = contactInterface.getObjectById(contactId, FolderObject.SYSTEM_LDAP_FOLDER_ID);
+        return contact;
     }
 
 
+    private String formatPrivacyText(String privacyText, String adminAddress, User user, Date creationDate) {
+        String date = new SimpleDateFormat("yyyy-MM-dd").format(creationDate);
+        String retVal = String.format(privacyText, adminAddress, user.getMail(), date);
+        return "<p>" +retVal.replaceAll("\n", "</p><p>") + "</p>";
+    }
+
+    private String getCollectionName(String module) {
+        return module;
+    }
+
     private Map<String, String> getPublicationArguments(HttpServletRequest req) throws UnsupportedEncodingException {
         String[] path = req.getPathInfo().split("/");
         List<String> normalized = new ArrayList<String>(path.length);
@@ -185,4 +251,17 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         args.put(SECRET, req.getParameter(SECRET));
         return args;
     }
+
+    private User getUser(Publication publication) throws UserException {
+        Context context = publication.getContext();
+        int uid = publication.getUserId();
+        User user = userService.getUser(uid, context);
+        return user;
+    }
+    
+    private String getPrivacyText(User user){
+        return translator.translate(user.getLocale(), MicroformatStrings.DISCLAIMER_PRIVACY);
+    }
+
+
 }
